import sys
import os

import mns_common.component.k_line.patterns.pattern_Enum as pattern_Enum

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)


# k线形态分类
def k_line_patterns_classify(open, close, high, low, max_chg, chg):
    if cross_star(open, close, high, low):
        return pattern_Enum.Pattern_Enum.CROSS_STAR
    elif down_over_lining(open, close, high, low):
        return pattern_Enum.Pattern_Enum.DOWN_OVER_LINING

    elif open_high_and_walk_low(open, close, high, low, max_chg, chg):
        return pattern_Enum.Pattern_Enum.OPEM_HIGH_AND_WALK_LOW

    elif up_over_lining(open, close, high, low):
        return pattern_Enum.Pattern_Enum.UP_OVER_LINING

    return pattern_Enum.Pattern_Enum.OTHER


# 十字星状态
def cross_star(open, close, high, low):
    if abs(open - close) < 0.01 * open and (high - max(open, close)) > 2 * (max(open, close) - min(open, close)) and (
            min(open, close) - low) > 2 * (max(open, close) - min(open, close)):
        return True
    else:
        return False


# 高开低走
def open_high_and_walk_low(open, close, high, low, max_chg, chg):
    if open > close and max_chg >= 7 and max_chg - chg >= 7:
        return True
    else:
        return False


# 下跌带长上影线
def down_over_lining(open, close, high, low):
    diff_chg_high = round((high - open) / open, 2)
    if open > close and diff_chg_high >= 7:
        return True
    else:
        return False


# 上涨带长上影线
def up_over_lining(open, close, high, low):
    diff_chg_high = round((high - open) / open, 2)
    if open < close and diff_chg_high >= 7:
        return True
    else:
        return False



import sys
import os
file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)

from threading import Thread


def async_fun(f):
    def inner_fun(*args, **kwargs):
        t = Thread(target=f, args=args, kwargs=kwargs)
        t.start()

    return inner_fun



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)

import json
from datetime import datetime
import requests
import pandas as pd
from loguru import logger

'''
concept_code:概念代码
code_list:概念对应下组成代码 长度小于898
获取概念入选详情
'''


def get_concept_explain(concept_code, code_list):
    # Define the URL and headers
    url = "http://eq.10jqka.com.cn/plateTimeSharing/index.php"
    params = {
        "con": "concept",
        "act": "getAnalysisData",
        "codeList": code_list,
        "plateCode": concept_code
    }
    headers = {
        "Host": "eq.10jqka.com.cn",
        "Accept": "*/*",
        "Cookie": 'IFUserCookieKey={"userid":"6039843748",'
                  '"escapename":"%25u666f%25u884cpM"};'
                  ' v=A-iUPPjIGuc01TZjuSWY1OIHvdz_EUwbLnUgn6IZNGNW_YfDSiEcq36F8CTx; '
                  'hxmPid=hqMarketPkgVersionControl; '
                  'escapename=%25u666f%25u884cpM;'
                  ' ticket=64f17cffa039bb0b46189c21f97036c6; '
                  'u_name=%BE%B0%D0%D0pM;'
                  ' user=MDq%2BsNDQcE06Ok5vbmU6NTAwOjYxMzk4NTQ0ODo3LDExMTExMTExMTExLDQwOzQ0LDExLDQwOzYsMSw0MDs1LDEsNDA7MSwxMDEsNDA7MiwxLDQwOzMsMSw0MDs1LDEsNDA7OCwwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMSw0MDsxMDIsMSw0MDoyNzo6OjYwMzk4NTQ0ODoxNzE4MTU2MTE4Ojo6MTYzNDU2Njk4MDoyNjc4NDAwOjA6MTQwNDg3ODkxMWJmY2IzYTVlZjcwOWIxMDdiYTQ2YjVhOjox; '
                  'user_status=0; userid=6039843748; voiceStatus=open',
        "User-Agent": "IHexin/11.50.61 (iPhone; iOS 17.5.1; Scale/3.00)",
        "Accept-Language": "zh-Hans-CN;q=1, en-GB;q=0.9, en-CN;q=0.8",
        "Accept-Encoding": "gzip, deflate, br",
        "Connection": "keep-alive"
    }
    try:
        # Make the GET request
        response = requests.get(url, headers=headers, params=params)

        # Print the response content
        result_json = response.json()
        status_code = result_json['status_code']
        status_msg = result_json['status_msg']
        if status_code == 0 and status_msg == 'ok':
            result_data = result_json['data']
            result_data_df = pd.DataFrame(result_data)
            return result_data_df
        else:
            return None
    except BaseException as e:
        logger.error("获取新概念入选信息异常:{}", e)
        return None


# 获取同花顺新概念信息--APP 端接口 容易被封
def get_ths_concept_detail_by_app(symbol: str = "886019") -> pd.DataFrame:
    current_time = datetime.now()
    # 将时间格式化成 Sat, 15 Jun 2024 02:18:53 GMT 这样的格式
    formatted_time = current_time.strftime('%a, %d %b %Y %H:%M:%S GMT')
    try:
        url = f'https://d.10jqka.com.cn/v2/blockrank/{symbol}/199112/d1000.js'
        # headers = {
        #     'Host': 'd.10jqka.com.cn',
        #     'Connection': 'keep-alive',
        #     'Accept': 'text/javascript, application/javascript, application/x-javascript',
        #     'User-Agent': "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36 NetType/WIFI MicroMessenger/7.0.20.1781(0x6700143B) WindowsWechat(0x63090a13) XWEB/9165 Flue",
        #     'Origin': 'https://m.10jqka.com.cn',
        #     'Sec-Fetch-Dest': 'empty',
        #     'Sec-Fetch-Mode': 'cors',
        #     'Sec-Fetch-Site': 'same-site',
        #     'Referer': 'https://m.10jqka.com.cn',
        #     'Accept-Encoding': 'gzip, deflate, br',
        #     'Accept-Language': 'zh-CN,zh;q=0.9',
        #     'If-Modified-Since': formatted_time
        # }

        headers = {
            'Accept': 'text/javascript, application/javascript, application/x-javascript',
            'Accept-Encoding': 'gzip, deflate, br, zstd',
            'Accept-Language': 'zh-CN,zh;q=0.9',
            'Connection': 'keep-alive',
            'Host': 'd.10jqka.com.cn',
            'Origin': 'https://m.10jqka.com.cn',
            'Referer': 'https://m.10jqka.com.cn/',
            'Sec-Fetch-Dest': 'empty',
            'Sec-Fetch-Mode': 'cors',
            'Sec-Fetch-Site': 'same-site',
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/125.0.0.0 Safari/537.36',
            'sec-ch-ua': '"Google Chrome";v="125", "Chromium";v="125", "Not.A/Brand";v="24"',
            'sec-ch-ua-mobile': '?0',
            'sec-ch-ua-platform': '"Windows"'
        }

        r = requests.get(url, headers=headers)
        result = r.content.decode("unicode-escape")

        start_index = result.index('{"block"')
        end_index = result.index('}]}')

        result = result[start_index:end_index + 3]

        data_json = json.loads(result)
        block = data_json['block']
        items = data_json['items']

        items_df = pd.DataFrame(items)
        items_df = items_df.rename(columns={
            "5": "symbol",
            "199112": "chg",
            "264648": "change",
            "2034120": "pe",
            "3475914": "flow_mv",
            "3541450": "total_mv",
            "1968584": "exchange",
            "10": "now_price",
            "7": "open",
            "8": "high",
            "9": "low",
            "13": "volume",
            "19": "amount",
            "55": "name",
            "6": "last_day_price",

        })
        items_df['concept_code'] = symbol
        items_df['concept_name'] = block['name']
        items_df['index'] = 0
        items_df['pct_chg'] = 0
        items_df['q_ratio'] = 0

        if 'change' not in items_df.columns:
            items_df['change'] = 0
        if 'exchange' not in items_df.columns:
            items_df['exchange'] = 0
        if 'q_ratio' not in items_df.columns:
            items_df['q_ratio'] = 0
        if 'pct_chg' not in items_df.columns:
            items_df['pct_chg'] = 0
        if 'pe' not in items_df.columns:
            items_df['pe'] = 0
        if 'flow_mv' not in items_df.columns:
            items_df['flow_mv'] = 0
        if 'total_mv' not in items_df.columns:
            items_df['total_mv'] = 0

        items_df = items_df[
            [
                'index',
                'symbol',
                'name',
                'now_price',
                'chg',
                'change',
                'exchange',
                'q_ratio',
                'pct_chg',
                'amount',
                'flow_mv',
                'total_mv',
                'pe',
                'concept_code',
                'concept_name',
            ]
        ]

        return items_df
    except BaseException as e:
        logger.error("(通过app分享链接)获取新概念信息异常:{},{}", symbol, e)
        return None


if __name__ == '__main__':
    ths_concept_detail = get_ths_concept_detail_by_app('881165')
    print(ths_concept_detail)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import re
import psutil
import subprocess
import pandas as pd
from loguru import logger

'''
cmd 操作方法
'''


# 执行bat文件 打开新的cmd窗口
def open_bat_file(bat_file):
    # 使用 subprocess 模块执行批处理文件
    try:
        subprocess.Popen(bat_file, creationflags=subprocess.CREATE_NEW_CONSOLE)
    except BaseException as e:
        logger.error("Error occurred:{}", e)


# 获取所有cmd bat窗口
def get_cmd_processes():
    cmd_processes_df = None
    for proc in psutil.process_iter(['pid', 'name', 'cmdline']):
        try:
            if proc.info['name'] == 'cmd.exe':
                process_pid = proc.pid
                process_name = proc.info['name']
                if len(proc.cmdline()) == 3:

                    sub_process_path = proc.cmdline()[2]
                    sub_process_path = sub_process_path.replace(' ', '')
                    sub_process_name = extract_bat_filename(sub_process_path)
                else:
                    sub_process_path = '/'
                    sub_process_name = ''
                if sub_process_name is None:
                    continue
                total_info = "".join(proc.cmdline())
                dict_result = {
                    "process_pid": process_pid,
                    "process_name": process_name,
                    "sub_process_path": sub_process_path,
                    "sub_process_name": sub_process_name,
                    "total_info": total_info
                }
                result_df = pd.DataFrame(dict_result, index=[0])
                if cmd_processes_df is None:
                    cmd_processes_df = result_df
                else:
                    cmd_processes_df = pd.concat([result_df, cmd_processes_df])

        except BaseException as e:
            logger.error("Error occurred:{}", e)
    return cmd_processes_df


# 关闭进程by pid
def kill_process_by_pid(pid):
    # 构建命令
    command = f'taskkill /PID {pid} /F'

    # 以管理员权限运行命令
    subprocess.run(command, shell=True, check=True)


# 关闭进程通过名称
def kill_process_by_name(process_name):
    # 遍历所有进程
    for proc in psutil.process_iter(['pid', 'name']):
        try:
            # 如果进程名称匹配，则终止该进程
            if proc.info['name'] == process_name:
                proc.kill()
                logger.info("Process {} with PID {} has been terminated.", process_name, proc.pid)
        except BaseException as e:
            logger.error("Error occurred:{}", e)


# 提取bat 后缀开结尾的
def extract_bat_filename(path):
    # 定义正则表达式模式
    pattern = re.compile(r'\\([^\\]+\.bat)$')

    # 搜索匹配的字符串
    match = pattern.search(path)

    if match:
        return match.group(1)  # 返回匹配的部分
    else:
        return None


# 获取所有进程
def get_all_process():
    all_process_df = None
    # 获取所有当前运行的进程
    for proc in psutil.process_iter(['pid', 'name', 'cmdline']):
        try:
            process_pid = proc.pid
            process_name = proc.info['name']
            if len(proc.cmdline()) == 3:

                sub_process_path = proc.cmdline()[2]
                sub_process_path = sub_process_path.replace(' ', '')
                sub_process_name = extract_bat_filename(sub_process_path)
            else:
                sub_process_path = '/'
                sub_process_name = ''
            if sub_process_name is None:
                continue
            total_info = "".join(proc.cmdline())
            result = {"process_pid": process_pid,
                      "process_name": process_name,
                      "sub_process_path": sub_process_path,
                      "sub_process_name": sub_process_name,
                      "total_info": total_info}
            result_df = pd.DataFrame(result, index=[0])
            if all_process_df is None:
                all_process_df = result_df
            else:
                all_process_df = pd.concat([all_process_df, result_df])
        except BaseException as e:
            pass
    return all_process_df


# 进程是否运行
def is_process_running(process_name):
    # 获取所有当前运行的进程
    for proc in psutil.process_iter(['name']):
        try:
            # 检查进程名称是否匹配
            if proc.info['name'] == process_name:
                return True
        except BaseException as e:
            logger.error("Error occurred:{}", e)
    return False


if __name__ == '__main__':
    #
    cmd_processes_df_list = get_all_process()
    print(cmd_processes_df_list)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')
import mns_common.constant.db_name_constant as db_name_constant
from functools import lru_cache
import requests
import mns_common.constant.self_choose_constant as self_choose_constant


# 获取自选板块信息
@lru_cache(maxsize=None)
def get_self_choose_plate_list():
    return mongodb_util.find_all_data(db_name_constant.SELF_CHOOSE_PLATE)


# 获取自选股票
@lru_cache()
def get_self_choose_stocks():
    self_choose_stocks_df = mongodb_util.find_all_data(db_name_constant.SELF_CHOOSE_STOCK)
    return self_choose_stocks_df


# 清除缓存
def clear_self_choose_cache():
    get_self_choose_stocks.cache_clear()
    get_self_choose_plate_list.cache_clear()


# 同花顺概念添加到客户端
def plate_add(param):
    total_url = "http://127.0.0.1:5000/api/self/choose/plate/add"
    headers = {
        "Content-Type": "application/json"
    }
    return requests.post(total_url, data=param, headers=headers)


# 个股添加
def symbol_add(param):
    total_url = "http://127.0.0.1:5000/api/self/choose/stock/add"
    headers = {
        "Content-Type": "application/json"
    }
    return requests.post(total_url, data=param, headers=headers)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import pandas as pd
import requests

# symbol 代码
# 北交所:0  深圳：0 上海：1
"""
获取分钟数据
"""


def get_minute_data(symbol, start_date, end_date, period,
                    adjust) -> pd.DataFrame:
    """
    东方财富网-行情首页-沪深京 A 股-每日分时行情
    https://quote.eastmoney.com/concept/sh603777.html?from=classic
    :param symbol: 股票代码
    :type symbol: str
    :param start_date: 开始日期
    :type start_date: str
    :param end_date: 结束日期
    :type end_date: str
    :param period: choice of {'1', '5', '15', '30', '60'}
    :type period: str
    :param adjust: choice of {'', 'qfq', 'hfq'}
    :type adjust: str
    :return: 每日分时行情
    :rtype: pandas.DataFrame
    """
    adjust_map = {
        "": "0",
        "qfq": "1",
        "hfq": "2",
    }
    if period == "1":
        url = "https://push2his.eastmoney.com/api/qt/stock/trends2/get"
        params = {
            "fields1": "f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f11,f12,f13",
            "fields2": "f51,f52,f53,f54,f55,f56,f57,f58",
            "ut": "7eea3edcaed734bea9cbfc24409ed989",
            "ndays": "5",
            "iscr": "0",
            "secid": symbol,
            "_": "1623766962675",
        }
        r = requests.get(url, timeout=15, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(
            [item.split(",") for item in data_json["data"]["trends"]]
        )
        temp_df.columns = [
            "time",
            "open",
            "close",
            "high",
            "low",
            "volume",
            "amount",
            "ava_price",
        ]
        temp_df.index = pd.to_datetime(temp_df["time"])
        temp_df = temp_df[start_date:end_date]
        temp_df.reset_index(drop=True, inplace=True)
        temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
        temp_df["close"] = pd.to_numeric(temp_df["close"], errors="coerce")
        temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")
        temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")
        temp_df["amount"] = pd.to_numeric(temp_df["amount"], errors="coerce")
        temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
        temp_df["ava_price"] = pd.to_numeric(temp_df["ava_price"], errors="coerce")
        temp_df["time"] = pd.to_datetime(temp_df["time"]).astype(str)
        return temp_df
    else:
        url = "https://push2his.eastmoney.com/api/qt/stock/kline/get"
        params = {
            "fields1": "f1,f2,f3,f4,f5,f6",
            "fields2": "f51,f52,f53,f54,f55,f56,f57,f58,f59,f60,f61",
            "ut": "7eea3edcaed734bea9cbfc24409ed989",
            "klt": period,
            "fqt": adjust_map[adjust],
            "secid": symbol,
            "beg": "0",
            "end": "20500000",
            "_": "1630930917857",
        }
        r = requests.get(url, timeout=15, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(
            [item.split(",") for item in data_json["data"]["klines"]]
        )
        temp_df.columns = [
            "time",
            "open",
            "close",
            "high",
            "low",
            "amount",
            "volume",
            "pct_chg",
            "chg",
            "change",
            "exchange",
        ]
        temp_df.index = pd.to_datetime(temp_df["time"])
        temp_df = temp_df[start_date:end_date]
        temp_df.reset_index(drop=True, inplace=True)
        temp_df["open"] = pd.to_numeric(temp_df["open"], errors="coerce")
        temp_df["close"] = pd.to_numeric(temp_df["close"], errors="coerce")
        temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")
        temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")
        temp_df["amount"] = pd.to_numeric(temp_df["amount"], errors="coerce")
        temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
        temp_df["pct_chg"] = pd.to_numeric(temp_df["pct_chg"], errors="coerce")
        temp_df["chg"] = pd.to_numeric(temp_df["chg"], errors="coerce")
        temp_df["change"] = pd.to_numeric(temp_df["change"], errors="coerce")
        temp_df["exchange"] = pd.to_numeric(temp_df["exchange"], errors="coerce")
        temp_df["time"] = pd.to_datetime(temp_df["time"]).astype(str)
        temp_df = temp_df[
            [
                "time",
                "volume",
                "close",
                "high",
                "low",
                "chg",
                "change",
                "amount",
                "volume",
                "pct_chg",
                "exchange",
            ]
        ]
        return temp_df


if __name__ == '__main__':
    test_df = get_minute_data('0.899050', start_date="2025-03-03 09:30:00",
                              end_date="2025-03-07 15:00:00", period="1", adjust="")
    print(test_df)



import os
import sys

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant

mongodb_util = MongodbUtil('27017')
from functools import lru_cache
import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api
import mns_common.utils.data_frame_util as data_frame_util


# 开盘啦概念操作类

# 获取单个股票所有概念数据
@lru_cache(maxsize=None)
def get_symbol_all_kpl_concept(symbol):
    query = {'symbol': symbol}
    return mongodb_util.find_query_data(db_name_constant.KPL_BEST_CHOOSE_INDEX_DETAIL, query)


# 获取单个kpl板块所有股票组成
@lru_cache(maxsize=None)
def get_one_plate_code_all_symbol(plate_code):
    query = {"plate_code": plate_code}
    return mongodb_util.find_query_data(db_name_constant.KPL_BEST_CHOOSE_INDEX_DETAIL, query)


# 获取所有开盘啦概念列表
@lru_cache(maxsize=None)
def get_kpl_all_concept():
    query = {}
    kpl_best_choose_index = mongodb_util.find_query_data(db_name_constant.KPL_BEST_CHOOSE_INDEX, query)
    return kpl_best_choose_index


# 获取开盘啦有效概念列表
@lru_cache(maxsize=None)
def get_valid_kpl_all_concept():
    all_kpl_concept_df = get_kpl_all_concept()

    return all_kpl_concept_df.loc[all_kpl_concept_df['valid']]


# 最近股票新添加ths概念 刚好这个模板在热炒中
def kpl_recent_add_new_concept(str_day, before_num, str_now_date):
    last_trade_day = trade_date_common_service_api.get_before_trade_date(str_day, before_num)
    if str_now_date is not None:
        # 上一个交易结束时间
        last_trade_end_time = last_trade_day + ' 15:00:00'

        query = {'$and': [{"create_time": {"$gte": last_trade_end_time}},
                          {"create_time": {"$lte": str_now_date}}],
                 'concept_type': 'kpl'}
    else:

        # 上一个交易结束时间
        last_trade_end_time = last_trade_day + ' 15:00:00'
        today_trade_begin_time = str_day + ' 15:00:00'
        query = {'$and': [{"create_time": {"$gte": last_trade_end_time}},
                          {"create_time": {"$lte": today_trade_begin_time}}],
                 'concept_type': 'kpl'}

    recent_add_new_concept_df = mongodb_util.find_query_data('today_new_concept_list', query)
    if data_frame_util.is_empty(recent_add_new_concept_df):
        return None
    return recent_add_new_concept_df[[
        'symbol',
        'name',
        'plate_code',
        'plate_name',
        'first_plate_code',
        'first_plate_name',
        'plate_name_list',
        'most_relative_name',
        'index_class',
        'sync_str_day',
        'sync_str_time'
    ]]


# 清除开盘啦概念缓存
def clear_kpl_concept_cache():
    get_kpl_all_concept.cache_clear()
    get_symbol_all_kpl_concept.cache_clear()
    get_valid_kpl_all_concept.cache_clear()


if __name__ == '__main__':
    df = get_valid_kpl_all_concept()
    df = get_valid_kpl_all_concept()
    clear_kpl_concept_cache()
    df = get_kpl_all_concept()



import sys
import os
file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.api.kpl.common.kpl_common_api as kpl_common_api


def get_industry_index():
    return kpl_common_api.get_plate_index(kpl_common_api.INDUSTRY)


def industry_index_detail(industry_code):
    return kpl_common_api.plate_detail_info(industry_code)


if __name__ == '__main__':
    industry_df = get_industry_index()

    df = industry_index_detail('881129')
    print(df)
